"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
// Import sheet and code components
const MitoSheet_1 = __importDefault(require("./MitoSheet"));
const SheetTab_1 = __importDefault(require("./SheetTab"));
const Error_1 = __importDefault(require("./Error"));
const FormulaBar_1 = __importDefault(require("./FormulaBar"));
const MitoToolbar_1 = __importDefault(require("./MitoToolbar"));
// Import css
require("../../css/mito.css");
class Mito extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            columnSpreadsheetCodeJSON: this.props.columnSpreadsheetCodeJSON,
            dfName: this.props.dfName,
            sheetJSON: this.props.sheetJSON,
            codeJSON: this.props.codeJSON,
            formulaBarValue: '',
            selectedColumn: '',
            selectedRowIndex: 0,
            errorJSON: undefined
        };
        this.cellFocused = this.cellFocused.bind(this);
        this.handleFormulaBarEdit = this.handleFormulaBarEdit.bind(this);
        this.handleFormulaBarSubmit = this.handleFormulaBarSubmit.bind(this);
        this.sendCellValueUpdate = this.sendCellValueUpdate.bind(this);
    }
    cellFocused(event) {
        const column = event.column.getColId();
        const columnIndex = this.state.sheetJSON.columns.indexOf(column);
        const rowIndex = event.rowIndex;
        const columnFormula = this.state.columnSpreadsheetCodeJSON[column];
        let formulaBarValue = '';
        if (columnFormula !== '') {
            // if the cell has a formula, then display the formula
            formulaBarValue = columnFormula.toString();
        }
        else {
            // if the cell does not have a formula, display the value
            formulaBarValue = this.state.sheetJSON.data[rowIndex][columnIndex];
        }
        // update state
        this.setState({
            selectedColumn: column,
            selectedRowIndex: rowIndex,
            formulaBarValue: formulaBarValue
        });
    }
    handleFormulaBarEdit(e) {
        this.setState({
            formulaBarValue: e.currentTarget.value
        });
    }
    // TODO: do we want a different type of edit for a value change and a formula change or will 
    // we just detect that in the backend and apply the correct edit rules?
    handleFormulaBarSubmit(e) {
        e.preventDefault();
        this.sendCellValueUpdate(this.state.selectedColumn, this.state.formulaBarValue);
    }
    // TODO: this event should be broken out into a formula edit and a value edit
    sendCellValueUpdate(column, newValue) {
        this.props.send({
            'event': 'edit_event',
            'type': 'cell_edit',
            'id': '123',
            'timestamp': '456',
            'address': column,
            'new_formula': newValue
        });
    }
    render() {
        return (react_1.default.createElement("div", { className: "mito-container" },
            react_1.default.createElement("div", { className: "mitosheet" },
                react_1.default.createElement(FormulaBar_1.default, { formulaBarValue: this.state.formulaBarValue, handleFormulaBarEdit: this.handleFormulaBarEdit, handleFormulaBarSubmit: this.handleFormulaBarSubmit }),
                react_1.default.createElement(MitoToolbar_1.default, { sheetJSON: this.state.sheetJSON, send: this.props.send }),
                react_1.default.createElement(MitoSheet_1.default, { sheetJSON: this.state.sheetJSON, cellFocused: this.cellFocused, send: this.props.send, sendCellValueUpdate: this.sendCellValueUpdate }),
                react_1.default.createElement("div", { key: this.state.dfName, className: "sheet-tab-bar" },
                    react_1.default.createElement(SheetTab_1.default, { sheetName: this.state.dfName }))),
            react_1.default.createElement("div", { className: "modal" },
                react_1.default.createElement(Error_1.default, { errorJSON: this.state.errorJSON, onClick: () => { this.setState({ errorJSON: undefined }); } }))));
    }
}
exports.default = Mito;
//# sourceMappingURL=Mito.js.map