"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
// Import sheet and code components
const MitoSheet_1 = __importDefault(require("./MitoSheet"));
const SheetTab_1 = __importDefault(require("./SheetTab"));
const FormulaBar_1 = __importDefault(require("./FormulaBar"));
const MitoToolbar_1 = __importDefault(require("./MitoToolbar"));
const DocumentationSidebar_1 = __importDefault(require("./DocumentationSidebar"));
// Import modals
const ErrorModal_1 = __importDefault(require("./ErrorModal"));
const RepeatAnalysisModal_1 = __importDefault(require("./RepeatAnalysisModal"));
// Import css
require("../../css/mito.css");
var ModalEnum;
(function (ModalEnum) {
    ModalEnum["None"] = "None";
    ModalEnum["Error"] = "Error";
    ModalEnum["RepeatAnalysis"] = "RepeatAnalysis";
})(ModalEnum = exports.ModalEnum || (exports.ModalEnum = {}));
class Mito extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.state = {
            columnSpreadsheetCodeJSON: this.props.columnSpreadsheetCodeJSON,
            dfName: this.props.dfName,
            sheetJSON: this.props.sheetJSON,
            formulaBarValue: this.props.sheetJSON.data[0][0],
            selectedColumn: this.props.sheetJSON.columns[0].toString(),
            selectedRowIndex: 0,
            documentationOpen: false,
            modal: ModalEnum.None,
            errorJSON: {
                event: '',
                type: '',
                header: '',
                to_fix: ''
            }
        };
        this.cellFocused = this.cellFocused.bind(this);
        this.handleFormulaBarEdit = this.handleFormulaBarEdit.bind(this);
        this.handleFormulaBarSubmit = this.handleFormulaBarSubmit.bind(this);
        this.sendCellValueUpdate = this.sendCellValueUpdate.bind(this);
        this.setDocumentation = this.setDocumentation.bind(this);
        this.setModal = this.setModal.bind(this);
        this.getCurrentModalComponent = this.getCurrentModalComponent.bind(this);
    }
    cellFocused(event) {
        const column = event.column.getColId();
        const columnIndex = this.state.sheetJSON.columns.indexOf(column);
        const rowIndex = event.rowIndex;
        if (column === 'index') {
            // if the index column is selected, clear the formula bar
            this.setState({
                selectedColumn: "index",
                selectedRowIndex: rowIndex,
                formulaBarValue: ""
            });
        }
        else {
            // if a non-index column is selected, get the formula
            const columnFormula = this.state.columnSpreadsheetCodeJSON[column];
            let formulaBarValue = '';
            if (columnFormula !== '') {
                // if the cell has a formula, then display the formula
                formulaBarValue = columnFormula;
            }
            else {
                // if the cell does not have a formula, display the value
                formulaBarValue = this.state.sheetJSON.data[rowIndex][columnIndex];
            }
            // update state
            this.setState({
                selectedColumn: column,
                selectedRowIndex: rowIndex,
                formulaBarValue: formulaBarValue
            });
        }
    }
    handleFormulaBarEdit(e) {
        this.setState({
            formulaBarValue: e.currentTarget.value
        });
    }
    // TODO: do we want a different type of edit for a value change and a formula change or will 
    // we just detect that in the backend and apply the correct edit rules?
    handleFormulaBarSubmit(e) {
        e.preventDefault();
        this.sendCellValueUpdate(this.state.selectedColumn, this.state.formulaBarValue);
    }
    // TODO: this event should be broken out into a formula edit and a value edit
    sendCellValueUpdate(column, newValue) {
        this.props.send({
            'event': 'edit_event',
            'type': 'cell_edit',
            'id': '123',
            'timestamp': '456',
            'address': column,
            'new_formula': newValue
        });
    }
    setDocumentation(documentationOpen) {
        this.setState({ documentationOpen: documentationOpen });
    }
    getCurrentModalComponent() {
        // Returns the JSX.element that is currently, open, and is used
        // in render to display this modal
        switch (this.state.modal) {
            case ModalEnum.None: return react_1.default.createElement("div", null);
            case ModalEnum.Error: return (react_1.default.createElement(ErrorModal_1.default, { errorJSON: this.state.errorJSON, setModal: this.setModal }));
            case ModalEnum.RepeatAnalysis: return (react_1.default.createElement(RepeatAnalysisModal_1.default, { setModal: this.setModal }));
        }
    }
    setModal(modal) {
        this.setState({
            'modal': modal
        });
    }
    render() {
        // set the selected cell for the cell indicator in the mito toolbar
        let selectedCell = this.state.selectedColumn + (this.state.selectedRowIndex + 1).toString();
        return (react_1.default.createElement("div", { className: "mito-container" },
            react_1.default.createElement("div", { className: "mitosheet" },
                react_1.default.createElement(MitoToolbar_1.default, { sheetJSON: this.state.sheetJSON, selectedCell: selectedCell, send: this.props.send, setDocumentation: this.setDocumentation, setModal: this.setModal }),
                react_1.default.createElement(FormulaBar_1.default, { formulaBarValue: this.state.formulaBarValue, handleFormulaBarEdit: this.handleFormulaBarEdit, handleFormulaBarSubmit: this.handleFormulaBarSubmit }),
                react_1.default.createElement(MitoSheet_1.default, { sheetJSON: this.state.sheetJSON, cellFocused: this.cellFocused, send: this.props.send, sendCellValueUpdate: this.sendCellValueUpdate }),
                react_1.default.createElement("div", { key: this.state.dfName, className: "sheet-tab-bar" },
                    react_1.default.createElement(SheetTab_1.default, { sheetName: this.state.dfName }))),
            this.getCurrentModalComponent(),
            this.state.documentationOpen &&
                react_1.default.createElement("div", { className: "sidebar" },
                    react_1.default.createElement(DocumentationSidebar_1.default, { setDocumentation: this.setDocumentation }))));
    }
}
exports.default = Mito;
//# sourceMappingURL=Mito.js.map