"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const ag_grid_react_1 = require("ag-grid-react");
require("ag-grid-community/dist/styles/ag-grid.css");
require("ag-grid-community/dist/styles/ag-theme-alpine.css");
require("../../css/mitosheet.css");
const MitoCellEditor_1 = __importDefault(require("./MitoCellEditor"));
const MitoCellEditor_2 = require("./MitoCellEditor");
// And functions for building components
const gridData_1 = require("../data-utils/gridData");
const MitoSheet = (props) => {
    function onGridReady(params) {
        if (window.gridApiMap === undefined) {
            window.gridApiMap = new Map();
        }
        window.gridApiMap.set(props.model_id, params.api);
    }
    const cellValueChanged = (e) => {
        const column = e.colDef.field ? e.colDef.field : "";
        const newValue = e.newValue;
        props.sendCellValueUpdate(column, newValue);
    };
    const columns = gridData_1.buildGridColumns(props.sheetJSON.columns, props.setEditingMode);
    const rowData = gridData_1.buildGridData(props.sheetJSON);
    const frameworkComponents = {
        simpleEditor: MitoCellEditor_1.default
    };
    return (react_1.default.createElement("div", null,
        react_1.default.createElement("div", { className: "ag-theme-alpine ag-grid" },
            react_1.default.createElement(ag_grid_react_1.AgGridReact, { onGridReady: onGridReady, onCellFocused: (e) => props.cellFocused(e), rowData: rowData, frameworkComponents: frameworkComponents, suppressKeyboardEvent: (params) => {
                    /*
                        While we're editing a cell, we suppress events that we use
                        to do things within the editor.

                        NOTE: this function should suppress the events matched in onKeyDown
                        in MitoCellEditor!
                    */
                    if (!params.editing) {
                        return false;
                    }
                    return MitoCellEditor_2.TAKE_SUGGESTION_KEYS.includes(params.event.key) ||
                        MitoCellEditor_2.ARROW_UP_KEYS.includes(params.event.key) ||
                        MitoCellEditor_2.ARROW_DOWN_KEYS.includes(params.event.key);
                }, onCellValueChanged: cellValueChanged }, columns))));
};
exports.default = MitoSheet;
//# sourceMappingURL=MitoSheet.js.map