"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const Mito_1 = require("../Mito");
const DefaultModal_1 = __importDefault(require("../DefaultModal"));
// import css
require("../../../css/margins.css");
require("../../../css/filter_modal.css");
var FilterCondition;
(function (FilterCondition) {
    FilterCondition["NONE"] = "none";
    FilterCondition["NUMBER_EXACTLY"] = "number_exactly";
    FilterCondition["GREATER"] = "greater";
    FilterCondition["GREATER_THAN_OR_EQUAL"] = "greater_than_or_equal";
    FilterCondition["LESS"] = "less";
    FilterCondition["LESS_THAN_OR_EQUAL"] = "less_than_or_equal";
    FilterCondition["EMPTY"] = "empty";
    FilterCondition["NOT_EMPTY"] = "not_empty";
    FilterCondition["CONTAINS"] = "contains";
    FilterCondition["STRING_EXACTLY"] = "string_exactly";
})(FilterCondition = exports.FilterCondition || (exports.FilterCondition = {}));
var FilterTypeIdentifier;
(function (FilterTypeIdentifier) {
    FilterTypeIdentifier["STRING"] = "string";
    FilterTypeIdentifier["NUMBER"] = "number";
})(FilterTypeIdentifier || (FilterTypeIdentifier = {}));
// if one of these filters are selected, don't display the value input
const noInputFilters = [FilterCondition.NONE, FilterCondition.EMPTY, FilterCondition.NOT_EMPTY];
function getFilterCondition(condition) {
    if (condition === 'none') {
        return FilterCondition.NONE;
    }
    else if (condition === 'number_exactly') {
        return FilterCondition.NUMBER_EXACTLY;
    }
    else if (condition === 'greater') {
        return FilterCondition.GREATER;
    }
    else if (condition === 'greater_than_or_equal') {
        return FilterCondition.GREATER_THAN_OR_EQUAL;
    }
    else if (condition === 'less') {
        return FilterCondition.LESS;
    }
    else if (condition === 'less_than_or_equal') {
        return FilterCondition.LESS_THAN_OR_EQUAL;
    }
    else if (condition === 'empty') {
        return FilterCondition.EMPTY;
    }
    else if (condition === 'not_empty') {
        return FilterCondition.NOT_EMPTY;
    }
    else if (condition === 'contains') {
        return FilterCondition.CONTAINS;
    }
    else if (condition === 'string_exactly') {
        return FilterCondition.STRING_EXACTLY;
    }
    else {
        return FilterCondition.NONE;
    }
}
/*
    A modal that allows a user to filter a column
*/
class FilterModal extends react_1.default.Component {
    constructor(props) {
        var _a;
        super(props);
        this.filterColumn = () => {
            var _a;
            (_a = window.logger) === null || _a === void 0 ? void 0 : _a.track({
                userId: window.user_id,
                event: 'button_filter_log_event',
                properties: {
                    'sheet_index': this.props.selectedSheetIndex,
                    'column': this.props.columnHeader,
                    'condition': this.state.filterColumnState.condition,
                    'value': this.state.filterColumnState.value,
                }
            });
            this.props.send({
                'event': 'edit_event',
                'type': 'filter',
                'sheet_index': this.props.selectedSheetIndex,
                'column': this.props.columnHeader,
                'condition': this.state.filterColumnState.condition,
                'value': this.state.filterColumnState.value,
                'id': '123',
                'timestamp': '456'
            });
            this.props.setModal({ type: Mito_1.ModalEnum.None });
        };
        this.setFilterModalState = (condition, value) => {
            /*
                We'd prefer to check this.state.filterColumnState.type, and case on that, but the compiler
                isn't smart enough to figure out the types - so we case on the type of the value instead.
            */
            if (typeof this.state.filterColumnState.value === 'string') {
                // We cast the value to a string, as we're working with strings
                const stringValue = String(value);
                const updatedFilterState = {
                    type: FilterTypeIdentifier.STRING,
                    condition: condition,
                    value: stringValue
                };
                this.setState({ filterColumnState: updatedFilterState });
            }
            else {
                // Otherwise, we're working a number
                // TODO: cast to make this a number
                const numberValue = Number(value);
                const updatedFilterState = {
                    type: FilterTypeIdentifier.NUMBER,
                    condition: condition,
                    value: numberValue
                };
                this.setState({ filterColumnState: updatedFilterState });
            }
        };
        this.state = {
            filterColumnState: props.columnFilterInfo,
            valueInput: props.columnFilterInfo.value ? (_a = props.columnFilterInfo.value) === null || _a === void 0 ? void 0 : _a.toString() : '' // value displayed in the input field, separated out to avoid unnecessary type casting
        };
        if (props.columnFilterInfo.value === '' && props.columnFilterInfo.type === FilterTypeIdentifier.NUMBER) {
            this.state.filterColumnState.value = 0;
        }
        this.filterColumn = this.filterColumn.bind(this);
        this.setFilterModalState = this.setFilterModalState.bind(this);
        this.handleConditionChange = this.handleConditionChange.bind(this);
        this.handleValueChange = this.handleValueChange.bind(this);
    }
    handleConditionChange(e) {
        const filterCondition = getFilterCondition(e.target.value);
        this.setFilterModalState(filterCondition, this.state.filterColumnState.value);
    }
    handleValueChange(e) {
        this.setState({
            valueInput: e.target.value
        });
        this.setFilterModalState(this.state.filterColumnState.condition, e.target.value);
    }
    render() {
        // only display the value input when the condition requires a value
        const displayValueInput = !noInputFilters.includes(this.state.filterColumnState.condition);
        return (react_1.default.createElement(DefaultModal_1.default, { header: `Filter ${this.props.columnHeader}`, modalType: Mito_1.ModalEnum.Filter, viewComponent: react_1.default.createElement(react_1.Fragment, null,
                react_1.default.createElement("div", { className: "filter-modal-container" },
                    react_1.default.createElement("div", { className: "mt-1 filter-modal-center" },
                        react_1.default.createElement("div", { className: "filter-modal-p-div" },
                            react_1.default.createElement("p", null, " Filter Condition ")),
                        react_1.default.createElement("select", { className: "filter-modal-input", value: this.state.filterColumnState.condition, onChange: this.handleConditionChange },
                            react_1.default.createElement("option", { value: FilterCondition.NONE }, "None"),
                            this.state.filterColumnState.type === FilterTypeIdentifier.NUMBER &&
                                react_1.default.createElement(react_1.default.Fragment, null,
                                    react_1.default.createElement("option", { value: FilterCondition.NUMBER_EXACTLY }, "="),
                                    react_1.default.createElement("option", { value: FilterCondition.GREATER }, ">"),
                                    react_1.default.createElement("option", { value: FilterCondition.GREATER_THAN_OR_EQUAL }, "\u2265"),
                                    react_1.default.createElement("option", { value: FilterCondition.LESS }, "<"),
                                    react_1.default.createElement("option", { value: FilterCondition.LESS_THAN_OR_EQUAL }, "\u2264")),
                            this.state.filterColumnState.type === FilterTypeIdentifier.STRING &&
                                react_1.default.createElement(react_1.default.Fragment, null,
                                    react_1.default.createElement("option", { value: FilterCondition.CONTAINS }, "contains"),
                                    react_1.default.createElement("option", { value: FilterCondition.STRING_EXACTLY }, "is exactly")),
                            react_1.default.createElement("option", { value: FilterCondition.EMPTY }, "is empty"),
                            react_1.default.createElement("option", { value: FilterCondition.NOT_EMPTY }, "is not empty"))),
                    displayValueInput &&
                        react_1.default.createElement("div", { className: "mt-2" },
                            react_1.default.createElement("div", { className: "filter-modal-p-div" },
                                react_1.default.createElement("p", null, " Filter Value ")),
                            react_1.default.createElement("input", { className: "filter-modal-input", value: this.state.valueInput, onChange: this.handleValueChange })))), buttons: react_1.default.createElement(react_1.Fragment, null,
                react_1.default.createElement("div", { className: 'modal-close-button modal-dual-button-left', onClick: () => { this.props.setModal({ type: Mito_1.ModalEnum.None }); } }, " Close "),
                react_1.default.createElement("div", { className: 'modal-action-button modal-dual-button-right', onClick: this.filterColumn },
                    " ",
                    "Filter")) }));
    }
}
exports.default = FilterModal;
//# sourceMappingURL=FilterModal.js.map