"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const Mito_1 = require("../Mito");
const DefaultModal_1 = __importDefault(require("../DefaultModal"));
// import css
require("../../../css/save-analysis-modal.css");
var ImportEnum;
(function (ImportEnum) {
    ImportEnum["SimpleImport"] = "simple_import";
    ImportEnum["RawPythonImport"] = "raw_python_import";
})(ImportEnum = exports.ImportEnum || (exports.ImportEnum = {}));
/*
  A modal that allows a user to save an analysis with the input
  name.
*/
const ImportModal = (props) => {
    const [importType, setImportType] = react_1.useState(ImportEnum.SimpleImport);
    // Params for a simple import
    const [importedFiles, setImportedFiles] = react_1.useState(props.fileNames.length > 0 ? [props.fileNames[0]] : []);
    //const [selectedFiles, setSelectedFiles] = useState<boolean[]>(props.fileNames.map(() => false));
    // Params for a raw Python import
    const [pythonCode, setPythonCode] = react_1.useState('');
    const [dfNamesString, setDfNamesString] = react_1.useState('');
    const [dfNameError, setDfNameError] = react_1.useState('');
    const changeImportType = (event) => {
        setImportType(event.target.value);
    };
    const updateImportedFile = (event, index) => {
        const newImports = [...importedFiles];
        newImports[index] = event.target.value;
        setImportedFiles(newImports);
    };
    const addNewFileImport = () => {
        const newImports = [...importedFiles];
        newImports.push(props.fileNames[0]);
        setImportedFiles(newImports);
    };
    const changePythonCode = (event) => {
        setPythonCode(event.target.value);
    };
    const changeDfNamesString = (event) => {
        setDfNamesString(event.target.value);
    };
    const clickImport = () => {
        var _a, _b;
        if (importType === ImportEnum.SimpleImport) {
            (_a = window.logger) === null || _a === void 0 ? void 0 : _a.track({
                userId: window.user_id,
                event: 'button_simple_import_log_event',
                properties: {
                    file_names: importedFiles
                }
            });
            props.send({
                'event': 'edit_event',
                'type': 'simple_import_edit',
                'file_names': importedFiles,
            });
            props.setModal({ type: Mito_1.ModalEnum.None });
        }
        else {
            // Short curcit early if the user provides an invalid name
            const dfNames = dfNamesString.split(',');
            for (let i = 0; i < dfNames.length; i++) {
                if (!pythonCode.includes(dfNames[i])) {
                    setDfNameError(`Error: ${dfNames[i]} is not a name of a variable in your code.`);
                    return;
                }
            }
            (_b = window.logger) === null || _b === void 0 ? void 0 : _b.track({
                userId: window.user_id,
                event: 'button_raw_python_import_log_event',
                properties: {
                    file_names: importedFiles
                }
            });
            props.send({
                'event': 'edit_event',
                'type': 'raw_python_import_edit',
                'python_code': pythonCode,
                'df_names': dfNames,
            });
            props.setModal({ type: Mito_1.ModalEnum.None });
        }
    };
    return (react_1.default.createElement(DefaultModal_1.default, { header: `Import Data`, modalType: Mito_1.ModalEnum.ReplayAnalysis, viewComponent: react_1.default.createElement(react_1.Fragment, null,
            react_1.default.createElement("div", null, "Import Method"),
            react_1.default.createElement("select", { className: 'merge-modal-sheet-dropdown', onChange: changeImportType },
                react_1.default.createElement("option", { key: ImportEnum.SimpleImport, value: ImportEnum.SimpleImport, selected: importType === ImportEnum.SimpleImport }, " Simple Import"),
                ";",
                react_1.default.createElement("option", { key: ImportEnum.RawPythonImport, value: ImportEnum.RawPythonImport, selected: importType === ImportEnum.RawPythonImport }, " Raw Python Import"),
                ";"),
            importType === ImportEnum.SimpleImport &&
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", null, "Files to Import"),
                    importedFiles.map((selectedFileName, importIndex) => {
                        return (react_1.default.createElement("select", { key: importIndex, className: 'merge-modal-sheet-dropdown', onChange: (e) => updateImportedFile(e, importIndex) }, props.fileNames.map((fileName) => {
                            return (react_1.default.createElement("option", { key: fileName, value: fileName, selected: importedFiles[importIndex] === fileName }, fileName));
                        })));
                    }),
                    react_1.default.createElement("div", { onClick: addNewFileImport }, "+ Add")),
            importType === ImportEnum.RawPythonImport &&
                react_1.default.createElement("div", null,
                    react_1.default.createElement("div", null, "Python Code"),
                    react_1.default.createElement("textarea", { rows: 5, value: pythonCode, onChange: changePythonCode }),
                    react_1.default.createElement("div", null, "Dataframe Names (comma seperated)"),
                    react_1.default.createElement("input", { value: dfNamesString, onChange: changeDfNamesString }),
                    dfNameError !== '' && dfNameError)), buttons: react_1.default.createElement(react_1.Fragment, null,
            react_1.default.createElement("div", { className: 'modal-close-button modal-dual-button-left', onClick: () => { props.setModal({ type: Mito_1.ModalEnum.None }); } }, " Close "),
            react_1.default.createElement("div", { className: 'modal-action-button modal-dual-button-right', onClick: clickImport }, " Import ")) }));
};
exports.default = ImportModal;
//# sourceMappingURL=SimpleImportModal.js.map